Index: base/trace_event/trace_event_impl.h |
diff --git a/base/trace_event/trace_event_impl.h b/base/trace_event/trace_event_impl.h |
index 50d33ca7da9129a62f1a4518381bb6bce4898033..33a85c9b6ce854f4e6b6cde748fe6abca8a015d2 100644 |
--- a/base/trace_event/trace_event_impl.h |
+++ b/base/trace_event/trace_event_impl.h |
@@ -18,7 +18,6 @@ |
#include "base/memory/ref_counted_memory.h" |
#include "base/memory/scoped_vector.h" |
#include "base/observer_list.h" |
-#include "base/single_thread_task_runner.h" |
#include "base/strings/string_util.h" |
#include "base/synchronization/condition_variable.h" |
#include "base/synchronization/lock.h" |
@@ -799,8 +798,8 @@ |
ThreadLocalBoolean thread_is_in_trace_event_; |
// Contains the message loops of threads that have had at least one event |
// added into the local event buffer. Not using SingleThreadTaskRunner |
// because we need to know the life time of the message loops. |
hash_set<MessageLoop*> thread_message_loops_; |
// For events which can't be added into the thread local buffer, e.g. events |
@@ -810,7 +809,7 @@ |
// Set when asynchronous Flush is in progress. |
OutputCallback flush_output_callback_; |
- scoped_refptr<SingleThreadTaskRunner> flush_task_runner_; |
+ scoped_refptr<MessageLoopProxy> flush_message_loop_proxy_; |
subtle::AtomicWord generation_; |
bool use_worker_thread_; |
@@ -799,8 +798,8 @@ |
ThreadLocalBoolean thread_is_in_trace_event_; |
// Contains the message loops of threads that have had at least one event |
- // added into the local event buffer. Not using SingleThreadTaskRunner |
- // because we need to know the life time of the message loops. |
+ // added into the local event buffer. Not using MessageLoopProxy because we |
+ // need to know the life time of the message loops. |
hash_set<MessageLoop*> thread_message_loops_; |
// For events which can't be added into the thread local buffer, e.g. events |